summaryrefslogtreecommitdiffstats
path: root/src/usr
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr')
-rw-r--r--src/usr/fapi2/test/fapi2Test.H10
-rwxr-xr-xsrc/usr/targeting/common/xmltohb/xmltohb.pl6
2 files changed, 9 insertions, 7 deletions
diff --git a/src/usr/fapi2/test/fapi2Test.H b/src/usr/fapi2/test/fapi2Test.H
index 00a9bac46..1b7b142ec 100644
--- a/src/usr/fapi2/test/fapi2Test.H
+++ b/src/usr/fapi2/test/fapi2Test.H
@@ -76,10 +76,12 @@ void test_fapi2Test(void)
fapi2GetParentTest();
FAPI_INF("<<fapi2GetParent exiting...");
- FAPI_INF(">>fapi2GetOtherEnd starting...");
- fapi2GetOtherEnd();
- FAPI_INF(">>fapi2GetOtherEnd exiting...");
+ //@TODO-Restore with RTC:151090
+ FAPI_INF(">>fapi2GetOtherEnd skipping!!!...");
+ //FAPI_INF(">>fapi2GetOtherEnd starting...");
+ //fapi2GetOtherEnd();
+ //FAPI_INF(">>fapi2GetOtherEnd exiting...");
}
};
-#endif \ No newline at end of file
+#endif
diff --git a/src/usr/targeting/common/xmltohb/xmltohb.pl b/src/usr/targeting/common/xmltohb/xmltohb.pl
index bf675a58e..597517af6 100755
--- a/src/usr/targeting/common/xmltohb/xmltohb.pl
+++ b/src/usr/targeting/common/xmltohb/xmltohb.pl
@@ -5787,9 +5787,9 @@ sub generateTargetingImage {
# Each target is 4 bytes # attributes, 8 bytes pointer
# to attribute list, 8 bytes pointer to attribute pointer
- # list, 4 x 8 byte pointers to association lists, for total
- # of 20 + 32 = 52 bytes per target
- $index *= (20 + 32); # length(N + quad + quad + 4x quad)
+ # list, 6 x 8 byte pointers to association lists, for total
+ # of 20 + 48 = 68 bytes per target
+ $index *= (20 + 48); # length(N + quad + quad + 6x quad)
$attrhash{$attributeId}->{default} = $index + $firstTgtPtr;
}
OpenPOWER on IntegriCloud